@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2022 The meson-python developers
+#
+# SPDX-License-Identifier: MIT
+
 # Configuration file for the Sphinx documentation builder.
 #
 # This file only contains a selection of the most common options. For a full
@@ -16,8 +20,7 @@ import mesonpy
 # -- Project information -----------------------------------------------------
 
 project = 'meson-python'
-copyright = '2021, Quansight Labs, Filipe Laíns'
-author = 'Filipe Laíns'
+copyright = '2021, The meson-python developers'
 
 # The short X.Y version
 version = mesonpy.__version__
@@ -33,7 +36,13 @@ release = mesonpy.__version__
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
+    'sphinx.ext.todo',
     'sphinx_autodoc_typehints',
+    'sphinx_contributors',
+    'sphinx_copybutton',
+    'sphinx_design',
+    'sphinxcontrib.spelling',
+    'sphinxext.opengraph',
 ]
 
 intersphinx_mapping = {
@@ -51,13 +60,42 @@ exclude_patterns = []
 
 default_role = 'any'
 
+todo_include_todos = True
+
 # -- Options for HTML output -------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
 html_theme = 'furo'
-html_title = f'mesonpy {version}'
+html_title = f'meson-python {version}'
+
+html_static_path = ['static']
+html_css_files = [
+    'css/contributors.css',
+]
+
+html_theme_options = {
+    'light_css_variables': {
+        'font-stack': (
+            'system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,'
+            'Helvetica,Arial,sans-serif,Apple Color Emoji,Segoe UI Emoji'
+        ),
+    },
+}
+
+
+# Spellchecking
+
+spelling_show_suggestions = True
+spelling_warning = True
+
+
+# Open Graph
+
+ogp_site_url = 'https://meson-python.readthedocs.io'
+ogp_site_name = 'meson-python documentation'
+
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
